==> anagog_flutter-1.2.0.tar.gz: android/src/main/kotlin/com/anagog/anagog_flutter/model/PluginConfig.kt <==
package com.anagog.anagog_flutter.model
import com.anagog.jedai.common.stats.Stats
import com.google.gson.annotations.SerializedName

data class PluginConfig(
    @SerializedName("userDefinedStats") val userDefined: Map<String, Any> = mutableMapOf(),
    @SerializedName("notificationChannelId") val notificationChannelId: String? = null,
    @SerializedName("foregroundChannelId") val foregroundChannelId: String? = null,
    @SerializedName("enableAudienceAnalytics") val enableAudienceAnalytics: Boolean = false,
    @SerializedName("foregroundAlwaysOn") val foregroundAlwaysOn: Boolean = false,
    @SerializedName("enableLatestMs") val enableLatestMs: Boolean = true,
    @SerializedName("enableCrashReports") val enableCrashReports: Boolean = false,
    @SerializedName("enableInternalLog") val enableInternalLog: Boolean = true,
    @SerializedName("clientName") val clientName : String? = null,
    @SerializedName("reportBaseUrl") val reportBaseUrl: String? = null,
    @SerializedName("manifestUrl") val manifestUrl: String? = null,
    @SerializedName("remoteConfigUrl") val remoteConfigUrl: String? = null,
    @SerializedName("usageReportUrl") val usageReportUrl: String? = null) {
    fun getUserDefinedStats(): Map<String, Stats.Type> {
        val userDefinedStats = mutableMapOf<String, Stats.Type>()
        userDefined.entries.forEach { entry ->
            when (entry.value) {
                "INTEGER" -> userDefinedStats[entry.key] = Stats.Type.USER_DEFINED_INTEGER
                "DECIMAL" -> userDefinedStats[entry.key] = Stats.Type.USER_DEFINED_DECIMAL
                else -> userDefinedStats[entry.key] = Stats.Type.USER_DEFINED_STRING
            }
        }
        return userDefinedStats
    }
}

==> anagog_flutter-1.2.4.tar.gz: android/src/main/kotlin/com/anagog/anagog_flutter/model/PluginConfig.kt <==
package com.anagog.anagog_flutter.model
import com.anagog.jedai.common.stats.Stats
import com.google.gson.annotations.SerializedName

internal data class PluginConfig(
    @SerializedName("userDefinedStats") val userDefined: Map<String, Any> = mutableMapOf(),
    @SerializedName("notificationChannelId") val notificationChannelId: String? = null,
    @SerializedName("foregroundChannelId") val foregroundChannelId: String? = null,
    @SerializedName("enableAudienceAnalytics") val enableAudienceAnalytics: Boolean = false,
    @SerializedName("foregroundMode") val foregroundMode: ForegroundMode = ForegroundMode.NEVER,
    @SerializedName("enableLatestMs") val enableLatestMs: Boolean = true,
    @SerializedName("enableCrashReports") val enableCrashReports: Boolean = false,
    @SerializedName("enableInternalLog") val enableInternalLog: Boolean = true,
    @SerializedName("clientName") val clientName : String? = null,
    @SerializedName("reportBaseUrl") val reportBaseUrl: String? = null,
    @SerializedName("manifestUrl") val manifestUrl: String? = null,
    @SerializedName("remoteConfigUrl") val remoteConfigUrl: String? = null,
    @SerializedName("usageReportUrl") val usageReportUrl: String? = null) {
    fun getUserDefinedStats(): Map<String, Stats.Type> {
        val userDefinedStats = mutableMapOf<String, Stats.Type>()
        userDefined.entries.forEach { entry ->
            when (entry.value) {
                "INTEGER" -> userDefinedStats[entry.key] = Stats.Type.USER_DEFINED_INTEGER
                "DECIMAL" -> userDefinedStats[entry.key] = Stats.Type.USER_DEFINED_DECIMAL
                else -> userDefinedStats[entry.key] = Stats.Type.USER_DEFINED_STRING
            }
        }
        return userDefinedStats
    }
}

internal enum class ForegroundMode{
    NEVER, ALWAYS, ON_DEMAND
}
